==> abbr-touch-2.0.1.tgz: package/README.md <==
# abbr-touch [![NPM version](http://img.shields.io/npm/v/abbr-touch.svg?style=flat)](https://www.npmjs.org/package/abbr-touch)

[![Build Status](http://img.shields.io/travis/Tyriar/abbr-touch.svg?style=flat)](https://travis-ci.org/Tyriar/abbr-touch)
[![Code Climate](http://img.shields.io/codeclimate/github/Tyriar/abbr-touch.svg?style=flat)](https://codeclimate.com/github/Tyriar/abbr-touch)

A library to make <abbr> element title attributes touch accessible.

[![Example usage: touching an <abbr> tag brings up a description](example.png)][1]


## Installing

```bash
# via bower
bower install --save abbr-touch

# via NPM
npm install --save abbr-touch
```


## Including

```html
<!-- Bower -->
<script src="bower_components/abbr-touch/abbr-touch.js"></script>

<!-- NPM -->
<script src="bower_components/abbr-touch/abbr-touch.js"></script>
```


## Usage

See [demo.html][2] for a deeper example.

```javascript
// default handler on document (alert)
abbrTouch();

// default handler, apply to descendants of #some-element
abbrTouch(document.querySelector('#some-element'));

// custom handler, apply to descendants of #some-element
abbrTouch(document.querySelector('#some-element'), myHandler);

function myHandler(target, title, touchX, touchY) {
  console.log(target);
  console.log(title);
  console.log(touchX);
  console.log(touchY);
}
```


## See also

- [touchtap-event][3]
- [abbr-fill.js][1]



  [1]: https://github.com/Tyriar/abbr-fill.js
  [2]: https://github.com/Tyriar/abbr-touch.js/blob/master/demo.html
  [3]: https://github.com/Tyriar/touchtap-event

==> abbr-touch-2.1.6.tgz: package/README.md <==
# abbr-touch [![NPM version](http://img.shields.io/npm/v/abbr-touch.svg?style=flat)](https://www.npmjs.org/package/abbr-touch)

[![Build Status](http://img.shields.io/travis/Tyriar/abbr-touch.svg?style=flat)](https://travis-ci.org/Tyriar/abbr-touch)
[![Code Climate](http://img.shields.io/codeclimate/github/Tyriar/abbr-touch.svg?style=flat)](https://codeclimate.com/github/Tyriar/abbr-touch)

abbr-touch is a tiny JavaScript library that makes the title attribute of `<abbr>` element touch accessible. It does so by utilising [touchtap-event][3] to only expose the functionality to touch-enabled devices, a custom touch handler can then be used to display `<abbr>`'s content any way you wish.

[![Example usage: touching an <abbr> tag brings up a description](example.png)][1]


## Install

```bash
npm install --save abbr-touch
```


## Include

```html
<script src="node_modules/abbr-touch/abbr-touch.js"></script>
```


## Usage

```javascript
// default handler on document (alert)
abbrTouch();

// default handler, apply to descendants of #some-element
abbrTouch(document.querySelector('#some-element'));

// custom handler, apply to descendants of #some-element
abbrTouch(document.querySelector('#some-element'), myHandler);

function myHandler(target, title, touchX, touchY) {
  console.log(target);
  console.log(title);
  console.log(touchX);
  console.log(touchY);
}
```

A deeper example of usage can be found in [demo.html][2]. A live demo can be viewed on [Growing with the Web][4].


## See also

- [touchtap-event][3]
- [abbr-fill.js][1]



  [1]: https://github.com/Tyriar/abbr-fill.js
  [2]: https://github.com/Tyriar/abbr-touch.js/blob/master/demo.html
  [3]: https://github.com/Tyriar/touchtap-event
  [4]: http://www.growingwiththeweb.com/projects/abbr-touch/
